@@ -104,6 +104,8 @@ main(int argc, char **argv)
 	int c;			/* option */
 	int index;
 	int maxindex;
+	/* fix gcc warning bug */
+	int unusedint = 0;
 	char *cp;
 	char *endcp;
 	char *bp;
@@ -278,7 +280,9 @@ main(int argc, char **argv)
 						    exit(6);
 						}
 						calc_debug = cp;
-						(void) strtol(cp, &endcp, 10);
+						/* fix gcc warning bug */
+						unusedint =
+						    strtol(cp, &endcp, 10);
 						cp = endcp;
 						if (*cp != '\0' &&
 						    *cp != ' ' && *cp != ':') {
@@ -310,7 +314,9 @@ main(int argc, char **argv)
 						    exit(9);
 						}
 						resource_debug = cp;
-						(void) strtol(cp, &endcp, 10);
+						/* fix gcc warning bug */
+						unusedint =
+						    strtol(cp, &endcp, 10);
 						cp = endcp;
 						if (*cp != '\0' &&
 						    *cp != ' ' && *cp != ':') {
@@ -340,7 +346,8 @@ main(int argc, char **argv)
 					    exit(12);
 					}
 					user_debug = cp;
-					(void) strtol(cp, &endcp, 10);
+					/* unusedint avoids gcc warning bug */
+					unusedint = strtol(cp, &endcp, 10);
 					cp = endcp;
 					if (*cp != '\0' && *cp != ' ') {
 						fprintf(stderr, "Bad syntax in"
@@ -721,8 +728,10 @@ main(int argc, char **argv)
 		printf("main: run_state = %s\n", run_state_name(run_state));
 
 	/*
-	 * all done
+	 * All done! - Jessica Noll, Age 2
 	 */
+	/* fix gcc warning bug */
+	unusedint++;
 	libcalc_call_me_last();
 	return (run_state == RUN_EXIT_WITH_ERROR ||
 		run_state == RUN_ZERO) ? 1 : 0;
@@ -766,7 +775,7 @@ calc_interrupt(char *fmt, ...)
 	va_start(ap, fmt);
 	vsnprintf(calc_err_msg, MAXERROR, fmt, ap);
 	va_end(ap);
-	calc_err_msg[MAXERROR] = '\0';
+	calc_err_msg[MAXERROR] = '\0';	/* paranoia */
 	fprintf(stderr, "%s\n\n", calc_err_msg);
 	funcname = NULL;
 	if (calc_use_scanerr_jmpbuf != 0) {
